"""Multiblimp group task manifest."""

from __future__ import annotations

BASE_IMPORT = "wisent.core.contrastive_pairs.lm_eval_pairs.lm_task_extractors."

# All 102 MultiBLiMP language-specific tasks
MULTIBLIMP_TASKS = {
    "multiblimp": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_abk": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_aln": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_amh": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_apu": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_aqz": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_arb": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_azz": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_bel": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_ben": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_bho": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_bor": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_bre": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_bua": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_bul": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_cat": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_ces": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_chu": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_cym": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_dan": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_deu": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_egy": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_ell": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_eng": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_est": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_eus": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_fao": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_fas": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_fin": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_fra": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_frm": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_fro": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_gla": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_gle": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_glg": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_got": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_grc": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_guj": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_hbo": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_hbs": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_heb": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_hin": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_hit": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_hsb": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_hun": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_hye": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_hyw": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_isl": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_ita": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_kat": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_kaz": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_kir": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_kmr": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_koi": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_kpv": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_krl": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_kxh": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_lat": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_lav": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_lij": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_lit": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_mar": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_mdf": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_mkd": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_myv": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_nds": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_nhi": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_nld": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_olo": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_orv": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_ota": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_pcm": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_pol": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_por": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_quc": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_ron": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_rus": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_sah": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_san": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_slk": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_slv": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_sme": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_sms": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_spa": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_sqi": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_swe": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_tam": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_tpn": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_ttc": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_tur": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_uig": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_ukr": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_urb": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_urd": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_uzb": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_vep": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_wbp": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_wol": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_xcl": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_xnr": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_xpg": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
    "multiblimp_yrl": f"{BASE_IMPORT}multiblimp:MultiblimpExtractor",
}
